# burstfit
Spectro-temporal modeling of FRBs

# Installation
```bash
git clone https://github.com/thepetabyteproject/burstfit
cd burstfit
pip install -r requirements.txt
python setup.py install
``` 

# Documentation
Have a look at our [docs](https://thepetabyteproject.github.io/burstfit/) for the documentation.

# Tutorials
Here are some [tutorial notebooks](https://github.com/thepetabyteproject/burstfit/tree/main/examples) to get you started.

**Note**:
To run the tutorial notebooks you would need to install `jupyter`.

# Citation